==> humhub-1.3.18.tar.gz: humhub-1.3.18/protected/humhub/modules/ldap/messages/fi/base.php <==
<?php
return array (
  'A TLS/SSL is strongly favored in production environments to prevent passwords from be transmitted in clear text.' => '',
  'Base DN' => '',
  'Defines the filter to apply, when login is attempted. %s replaces the username in the login action. Example: &quot;(sAMAccountName=%s)&quot; or &quot;(uid=%s)&quot;' => '',
  'E-Mail Address Attribute' => 'Sähköpostiosoitteen määrite',
  'Enable LDAP Support' => 'Ota LDAP-tuki käyttöön',
  'Encryption' => 'Salaus',
  'Fetch/Update Users Automatically' => 'Hae/päivitä käyttäjät automaattisesti',
  'Hostname' => 'Isäntäpalvelin',
  'ID Attribute' => 'ID määrite',
  'LDAP' => 'LDAP',
  'LDAP Attribute for E-Mail Address. Default: &quotmail&quot;' => '',
  'LDAP Attribute for Username. Example: &quotuid&quot; or &quot;sAMAccountName&quot;' => '',
  'Limit access to users meeting this criteria. Example: &quot(objectClass=posixAccount)&quot; or &quot;(&(objectClass=person)(memberOf=CN=Workers,CN=Users,DC=myDomain,DC=com))&quot;' => '',
  'Login Filter' => 'Kirjautumissuodatin',
  'Not changeable LDAP attribute to unambiguously identify the user in the directory. If empty the user will be determined automatically by e-mail address or username. Examples: objectguid (ActiveDirectory) or uidNumber (OpenLDAP)' => '',
  'Password' => 'Salasana',
  'Port' => 'Portti',
  'Specify your LDAP-backend used to fetch user accounts.' => 'Määritä LDAP-backend, jota käytetään käyttäjätilijen hakemiseen.',
  'Status: Error! (Message: {message})' => 'Tila: Virhe! (Message: {message})',
  'Status: OK! ({userCount} Users)' => 'Tila: OK! ({userCount} Users)',
  'Status: Warning! (No users found using the ldap user filter!)' => '',
  'The default base DN used for searching for accounts.' => '',
  'The default credentials password (used only with username above).' => '',
  'The default credentials username. Some servers require that this be in DN form. This must be given in DN form if the LDAP server requires a DN to bind and binding should be possible with simple usernames.' => '',
  'User Filer' => 'Käyttäjän tiedostoija',
  'Username' => 'Käyttäjätunnus',
  'Username Attribute' => 'Käyttäjätunnuksen määrite',
);

==> humhub-1.4.2.tar.gz: humhub-1.4.2/protected/humhub/modules/ldap/messages/fi/base.php <==
<?php
return array (
  'A TLS/SSL is strongly favored in production environments to prevent passwords from be transmitted in clear text.' => '',
  'Base DN' => 'Perus DN',
  'Defines the filter to apply, when login is attempted. %s replaces the username in the login action. Example: &quot;(sAMAccountName=%s)&quot; or &quot;(uid=%s)&quot;' => '',
  'E-Mail Address Attribute' => 'Sähköpostiosoitteen määrite',
  'Enable LDAP Support' => 'Ota LDAP-tuki käyttöön',
  'Encryption' => 'Salaus',
  'Fetch/Update Users Automatically' => 'Hae/päivitä käyttäjät automaattisesti',
  'Hostname' => 'Isäntäpalvelin',
  'ID Attribute' => 'ID määrite',
  'LDAP' => 'LDAP',
  'LDAP Attribute for E-Mail Address. Default: &quotmail&quot;' => '',
  'LDAP Attribute for Username. Example: &quotuid&quot; or &quot;sAMAccountName&quot;' => '',
  'Limit access to users meeting this criteria. Example: &quot(objectClass=posixAccount)&quot; or &quot;(&(objectClass=person)(memberOf=CN=Workers,CN=Users,DC=myDomain,DC=com))&quot;' => '',
  'Login Filter' => 'Kirjautumissuodatin',
  'Not changeable LDAP attribute to unambiguously identify the user in the directory. If empty the user will be determined automatically by e-mail address or username. Examples: objectguid (ActiveDirectory) or uidNumber (OpenLDAP)' => 'Ei muutettavissa oleva LDAP-attribuuttia, jolla käyttäjä tunnistetaan yksiselitteisesti hakemistosta. Jos tyhjä käyttäjä määritetään automaattisesti sähköpostiosoitteella tai käyttäjätunnuksella. Esimerkkejä: objectguid (ActiveDirectory) tai uidNumber (OpenLDAP)',
  'Password' => 'Salasana',
  'Port' => 'Portti',
  'Specify your LDAP-backend used to fetch user accounts.' => 'Määritä LDAP-backend, jota käytetään käyttäjätilijen hakemiseen.',
  'Status: Error! (Message: {message})' => 'Tila: Virhe! (Message: {message})',
  'Status: OK! ({userCount} Users)' => 'Tila: OK! ({userCount} Users)',
  'Status: Warning! (No users found using the ldap user filter!)' => '',
  'The default base DN used for searching for accounts.' => '',
  'The default credentials password (used only with username above).' => '',
  'The default credentials username. Some servers require that this be in DN form. This must be given in DN form if the LDAP server requires a DN to bind and binding should be possible with simple usernames.' => '',
  'User Filer' => 'Käyttäjän tiedostoija',
  'Username' => 'Käyttäjätunnus',
  'Username Attribute' => 'Käyttäjätunnuksen määrite',
);
